InterventionEvent
=================

.. currentmodule:: pqp.symbols

.. autoclass:: InterventionEvent
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~InterventionEvent.assign
      ~InterventionEvent.get_var
      ~InterventionEvent.to_latex

   .. rubric:: Methods Documentation

   .. automethod:: assign
   .. automethod:: get_var
   .. automethod:: to_latex
